==> kubernetes-model-admissionregistration-4.13.3-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/MutatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface MutatingWebhookConfigurationFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookConfigurationFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public MutatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToWebhooks(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public A setToWebhooks(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook... items);
    public A addAllToWebhooks(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> items);
    public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook... items);
    public A removeAllFromWebhooks(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> items);
    public A removeMatchingFromWebhooks(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildWebhooks instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> getWebhooks();
    public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> buildWebhooks();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildWebhook(int index);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildFirstWebhook();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildLastWebhook();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildMatchingWebhook(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    public Boolean hasMatchingWebhook(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    public A withWebhooks(List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> webhooks);
    public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook... webhooks);
    public Boolean hasWebhooks();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<MutatingWebhookConfigurationFluent.MetadataNested<N>> {

        public N and();
        public N endMetadata();    }


    public interface WebhooksNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookFluent<MutatingWebhookConfigurationFluent.WebhooksNested<N>> {

        public N and();
        public N endWebhook();    }


}

==> kubernetes-model-admissionregistration-5.0.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/MutatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface MutatingWebhookConfigurationFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookConfigurationFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public MutatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
    public MutatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToWebhooks(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public A setToWebhooks(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook... items);
    public A addAllToWebhooks(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> items);
    public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook... items);
    public A removeAllFromWebhooks(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> items);
    public A removeMatchingFromWebhooks(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildWebhooks instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> getWebhooks();
    public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> buildWebhooks();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildWebhook(int index);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildFirstWebhook();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildLastWebhook();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook buildMatchingWebhook(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    public Boolean hasMatchingWebhook(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    public A withWebhooks(List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook> webhooks);
    public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook... webhooks);
    public Boolean hasWebhooks();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhook item);
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
    public MutatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookBuilder> predicate);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<MutatingWebhookConfigurationFluent.MetadataNested<N>> {

        public N and();
        public N endMetadata();    }


    public interface WebhooksNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookFluent<MutatingWebhookConfigurationFluent.WebhooksNested<N>> {

        public N and();
        public N endWebhook();    }


}
